@@ -8,12 +8,12 @@
 **	it under the terms of the GNU General Public License as published by
 **	the Free Software Foundation; either version 2 of the License, or
 **	(at your option) any later version.
-** 
+**
 **	This program is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **	GNU General Public License for more details.
-** 
+**
 **	You should have received a copy of the GNU General Public License
 **	along with this program; if not, write to the Free Software
 **	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -34,24 +34,18 @@
 //
 // DESCRIPTION
 //
-//	A ResultsMax is-a conf_int containing the maximum number of results
-//	to return from a search.
+//	A ResultsMax is-a conf_int containing the maximum number of results to
+//	return from a search.
 //
 //	This is the same as search's -m command-line option.
 //
 //*****************************************************************************
 {
 public:
-	ResultsMax() : conf<int>( "ResultsMax", ResultsMax_Default, 1 ) { }
-
-	ResultsMax& operator=( int i ) {
-		conf<int>::operator=( i );
-		return *this;
-	}
-	ResultsMax& operator=( char const *s ) {
-		conf<int>::operator=( s );
-		return *this;
-	}
+	ResultsMax() : conf<int>( "ResultsMax", ResultsMax_Default ) { }
+	CONF_INT_ASSIGN_OPS( ResultsMax )
 };
 
+extern ResultsMax max_results;
+
 #endif	/* ResultsMax_H */
