@@ -8,12 +8,12 @@
 **	it under the terms of the GNU General Public License as published by
 **	the Free Software Foundation; either version 2 of the License, or
 **	(at your option) any later version.
-** 
+**
 **	This program is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **	GNU General Public License for more details.
-** 
+**
 **	You should have received a copy of the GNU General Public License
 **	along with this program; if not, write to the Free Software
 **	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -42,15 +42,9 @@
 {
 public:
 	StemWords() : conf<bool>( "StemWords", false ) { }
-
-	StemWords& operator=( bool b ) {
-		conf<bool>::operator=( b );
-		return *this;
-	}
-	StemWords& operator=( char const *s ) {
-		conf<bool>::operator=( s );
-		return *this;
-	}
+	CONF_BOOL_ASSIGN_OPS( StemWords )
 };
 
+extern StemWords stem_words;
+
 #endif	/* StemWords_H */
