@@ -8,12 +8,12 @@
 **	it under the terms of the GNU General Public License as published by
 **	the Free Software Foundation; either version 2 of the License, or
 **	(at your option) any later version.
-** 
+**
 **	This program is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **	GNU General Public License for more details.
-** 
+**
 **	You should have received a copy of the GNU General Public License
 **	along with this program; if not, write to the Free Software
 **	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -34,8 +34,8 @@
 //
 // DESCRIPTION
 //
-//	A TitleLines is-a conf<int> containing the number of lines to look at
-//	for a <TITLE> tag.
+//	A TitleLines is-a conf<int> containing the number of lines to look into
+//	a file for its "title" (whatever that means for a given file format).
 //
 //	This is the same as index's -t command-line option.
 //
@@ -43,15 +43,9 @@
 {
 public:
 	TitleLines() : conf<int>( "TitleLines", TitleLines_Default ) { }
-
-	TitleLines& operator=( int i ) {
-		conf<int>::operator=( i );
-		return *this;
-	}
-	TitleLines& operator=( char const *s ) {
-		conf<int>::operator=( s );
-		return *this;
-	}
+	CONF_INT_ASSIGN_OPS( TitleLines )
 };
 
+extern TitleLines num_title_lines;
+
 #endif	/* TitleLines_H */
