@@ -8,12 +8,12 @@
 **	it under the terms of the GNU General Public License as published by
 **	the Free Software Foundation; either version 2 of the License, or
 **	(at your option) any later version.
-** 
+**
 **	This program is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **	GNU General Public License for more details.
-** 
+**
 **	You should have received a copy of the GNU General Public License
 **	along with this program; if not, write to the Free Software
 **	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -24,6 +24,11 @@
 
 // local
 #include "conf_set.h"
+#include "platform.h"
+
+#ifndef	PJL_NO_NAMESPACES
+using namespace std;
+#endif
 
 //*****************************************************************************
 //
@@ -33,8 +38,8 @@
 //
 // DESCRIPTION
 //
-//	Parse the line of text by splitting it into words that are separated
-//	by whitespace.
+//	Parse the line of text by splitting it into words that are separated by
+//	whitespace.
 //
 // PARAMETERS
 //
@@ -43,5 +48,5 @@
 //*****************************************************************************
 {
 	for ( register char const *s; s = ::strtok( line, " \r\t" ); line = 0 )
-		insert( ::strdup( s ) );
+		insert( s );
 }
