@@ -8,12 +8,12 @@
 **	it under the terms of the GNU General Public License as published by
 **	the Free Software Foundation; either version 2 of the License, or
 **	(at your option) any later version.
-** 
+**
 **	This program is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **	GNU General Public License for more details.
-** 
+**
 **	You should have received a copy of the GNU General Public License
 **	along with this program; if not, write to the Free Software
 **	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,14 +22,16 @@
 #ifndef directory_H
 #define directory_H
 
+// standard
+#include <map>
+
 // local
-#include "platform.h"
-#ifndef	PJL_NO_SYMBOLIC_LINKS
-#include "FollowLinks.h"
+#include "less.h"
 
-extern FollowLinks	follow_symbolic_links;
-#endif
-
-void			do_directory( char const *path );
+typedef std::map< char const*, int > dir_set_type;
+extern dir_set_type dir_set;
+//
+//	This contains a map of all directory paths and an int that gives its
+//	index (the directory number in the order encountered).
 
 #endif	/* directory_H */
