@@ -38,8 +38,8 @@
 // local
 #include "platform.h"
 #include "AssociateMeta.h"
-#include "bcd.h"
 #include "config.h"
+#include "enc_int.h"
 #include "ExcludeFile.h"
 #include "ExcludeMeta.h"
 #include "exit_codes.h"
@@ -54,8 +54,8 @@
 #include "IncludeFile.h"
 #include "IncludeMeta.h"
 #include "Incremental.h"
-#include "IndexFile.h"
 #include "indexer.h"
+#include "IndexFile.h"
 #include "index_segment.h"
 #include "itoa.h"
 #include "meta_map.h"
@@ -71,7 +71,9 @@
 #include "version.h"
 #include "WordFilesMax.h"
 #include "word_info.h"
+#include "word_markers.h"
 #include "WordPercentMax.h"
+#include "WordThreshold.h"
 #include "word_util.h"
 
 #ifndef	PJL_NO_NAMESPACES
@@ -79,6 +81,12 @@ using namespace PJL;
 using namespace std;
 #endif
 
+static long const	Rank_Factor = 10000000;
+//			A scaling factor used in rank calculation.
+//			Empirically, this was found to be a good number:
+//			higher, the results don't get better; lower, the
+//			results get more striated.
+
 AssociateMeta		associate_meta;
 ExcludeFile		exclude_patterns;	// do not index these
 IncludeFile		include_patterns;	// do index these
@@ -89,32 +97,33 @@ FilterFile		file_filters;
 Incremental		incremental;
 char const*		me;			// executable name
 meta_map		meta_names;
-int			num_examined_files;
-int			num_temp_files;
+static int		num_examined_files;
+static int		num_temp_files;
 TitleLines		num_title_lines;
-long			num_total_words;	// over all files indexed
-long			num_indexed_words;	// over all files indexed
-long			num_unique_words;	// over all files indexed
-vector<string>		partial_index_file_names;
+unsigned long		num_total_words;	// over all files indexed
+unsigned long		num_indexed_words;	// over all files indexed
+static unsigned long	num_unique_words;	// over all files indexed
+static vector<string>	partial_index_file_names;
 RecurseSubdirs		recurse_subdirectories;
 string			temp_file_name_prefix;
 Verbosity		verbosity;		// how much to print
 word_map		words;			// the index being generated
 WordFilesMax		word_file_max;
 WordPercentMax		word_percent_max;
+WordThreshold		word_threshold;
 
-void			load_old_index( char const *index_file_name );
-void			merge_indicies( ostream& );
-void			rank_full_index();
+static void		load_old_index( char const *index_file_name );
+static void		merge_indicies( ostream& );
+static void		rank_full_index();
 extern "C" void		remove_temp_files( void );
-ostream&		usage( ostream& = cerr );
-void			write_dir_index( ostream&, off_t* );
-void			write_file_index( ostream&, off_t* );
-void			write_full_index( ostream& );
-void			write_meta_name_index( ostream&, off_t* );
-void			write_partial_index();
-void			write_stop_word_index( ostream&, off_t* );
-void			write_word_index( ostream&, off_t* );
+static ostream&		usage( ostream& = cerr );
+static void		write_dir_index( ostream&, off_t* );
+static void		write_file_index( ostream&, off_t* );
+static void		write_full_index( ostream& );
+static void		write_meta_name_index( ostream&, off_t* );
+static void		write_partial_index();
+static void		write_stop_word_index( ostream&, off_t* );
+static void		write_word_index( ostream&, off_t* );
 
 #define	INDEX
 #include "do_file.c"
@@ -210,7 +219,7 @@ void			write_word_index( ostream&, off_t* );
 		"help",			0, '?',
 		"no-assoc-meta",	0, 'A',
 		"config-file",		1, 'c',
-#ifdef	mod_html
+#ifdef	MOD_html
 		"no-class",		1, 'C',
 #endif
 		"pattern",		1, 'e',
@@ -218,7 +227,7 @@ void			write_word_index( ostream&, off_t* );
 		"file-max",		1, 'f',
 		"files-reserve",	1, 'F',
 		"files-grow",		1, 'g',
-#ifdef	mod_html
+#ifdef	MOD_html
 		"dump-html",		0, 'H',
 #endif
 		"index-file",		1, 'i',
@@ -236,6 +245,7 @@ void			write_word_index( ostream&, off_t* );
 		"temp-dir",		1, 'T',
 		"verbosity",		1, 'v',
 		"version",		0, 'V',
+		"word-threshold",	1, 'W',
 		0
 	};
 
@@ -259,6 +269,7 @@ void			write_word_index( ostream&, off_t* );
 	char const*	verbosity_arg = 0;
 	char const*	word_file_max_arg = 0;
 	char const*	word_percent_max_arg = 0;
+	char const*	word_threshold_arg = 0;
 
 	option_stream::spec *const
 		all_options = indexer::all_mods_options( opt_spec );
@@ -369,6 +380,10 @@ void			write_word_index( ostream&, off_t* );
 				cout << "SWISH++ " << version << endl;
 				::exit( Exit_Success );
 
+			case 'W': // Word threshold.
+				word_threshold_arg = opt.arg();
+				break;
+
 			default: // Any indexing module claim the option?
 				if ( !indexer::any_mod_claims_option( opt ) )
 					cerr << usage;
@@ -410,6 +425,8 @@ void			write_word_index( ostream&, off_t* );
 		word_file_max = word_file_max_arg;
 	if ( word_percent_max_arg )
 		word_percent_max = word_percent_max_arg;
+	if ( word_threshold_arg )
+		word_threshold = word_threshold_arg;
 
 	indexer::all_mods_post_options();
 
@@ -634,11 +651,11 @@ void			write_word_index( ostream&, off_t* );
 	FOR_EACH( index_segment, old_files, f ) {
 		unsigned char const*
 			u = reinterpret_cast<unsigned char const*>( *f );
-		int const dir_index = parse_bcd( u );
+		int const dir_index = dec_int( u );
 		char const *const file_name = reinterpret_cast<char const*>(u);
 		while ( *u++ ) ;		// skip past filename
-		size_t const size = parse_bcd( u );
-		int const num_words = parse_bcd( u );
+		size_t const size = dec_int( u );
+		int const num_words = dec_int( u );
 		char const *const title = reinterpret_cast<char const*>( u );
 
 		string const dir_str( old_dirs[ dir_index ] );
@@ -656,7 +673,7 @@ void			write_word_index( ostream&, off_t* );
 		unsigned char const*
 			p = reinterpret_cast<unsigned char const*>( *m );
 		while ( *p++ ) ;		// skip past meta name
-		meta_names[ new_strdup( *m ) ] = parse_bcd( p );
+		meta_names[ new_strdup( *m ) ] = dec_int( p );
 	}
 
 	partial_index_file_names.push_back( index_file_name );
@@ -684,7 +701,7 @@ void			write_word_index( ostream&, off_t* );
 //				file.
 //
 //	factor			This should be precomputed to be the value of
-//				10000.0 divided by the total number of
+//				Rank_Factor divided by the total number of
 //				occurrences across all files.  This number is
 //				constant for a given word, hence the
 //				precomputation.
@@ -701,7 +718,7 @@ void			write_word_index( ostream&, off_t* );
 //
 //*****************************************************************************
 {
-	int r = int(
+	int const r = int(
 		( ::log( occurences_in_file ) + 10 ) * factor
 		/ file_info::ith_info( file_index )->num_words()
 	);
@@ -867,10 +884,11 @@ void			write_word_index( ostream&, off_t* );
 			FOR_EACH( file_list, list, file )
 				total_occurrences += file->occurrences_;
 		}
-		double const factor = 10000.0 / total_occurrences;
+		double const factor = (double)Rank_Factor / total_occurrences;
 
 		////////// Copy all index info and compute ranks //////////////
 
+		bool continues = false;
 		for ( j = i; j < partial_index_file_names.size(); ++j ) {
 			if ( word[ j ] == words[ j ].end() )
 				continue;
@@ -878,17 +896,22 @@ void			write_word_index( ostream&, off_t* );
 				continue;
 			file_list const list( word[ j ] );
 			FOR_EACH( file_list, list, file ) {
-				o << bcd( file->index_ );
+				if ( continues )
+					o << Word_Entry_Continues_Marker;
+				else
+					continues = true;
+				o << enc_int( file->index_ )
+				  << enc_int( file->occurrences_ )
+				  << enc_int( rank(
+					file->index_, file->occurrences_, factor
+				     ) );
 				if ( !file->meta_ids_.empty() )
 					file->write_meta_ids( o );
-				o << bcd( file->occurrences_ ) << bcd( rank(
-					file->index_, file->occurrences_, factor
-				) );
 			}
 
 			if ( j != i ) ++word[ j ];
 		}
-		o << '\xFF';
+		o << Stop_Marker;
 
 		++word[ i ];
 	}
@@ -912,19 +935,26 @@ void			write_word_index( ostream&, off_t* );
 			file_list const list( word[ j ] );
 			FOR_EACH( file_list, list, file )
 				total_occurrences += file->occurrences_;
-			double const factor = 10000.0 / total_occurrences;
+			double const factor =
+				(double)Rank_Factor / total_occurrences;
 
 			////////// Copy all index info and compute ranks //////
 
+			bool continues = false;
 			FOR_EACH( file_list, list, file ) {
-				o << bcd( file->index_ );
+				if ( continues )
+					o << Word_Entry_Continues_Marker;
+				else
+					continues = true;
+				o << enc_int( file->index_ )
+				  << enc_int( file->occurrences_ )
+				  << enc_int( rank(
+					file->index_, file->occurrences_, factor
+				  ) );
 				if ( !file->meta_ids_.empty() )
 					file->write_meta_ids( o );
-				o << bcd( file->occurrences_ ) << bcd( rank(
-					file->index_, file->occurrences_, factor
-				) );
 			}
-			o << '\xFF';
+			o << Stop_Marker;
 		}
 	}
 
@@ -963,7 +993,7 @@ void			write_word_index( ostream&, off_t* );
 	if ( verbosity > 1 )
 		cout << '\n' << me << ": ranking index..." << flush;
 
-	TRANSFORM_EACH( word_map, words, w ) {
+	for ( word_map::iterator w = words.begin(); w != words.end(); ) {
 		word_info &info = w->second;
 
 		if ( is_too_frequent( w->first.c_str(), info.files_.size() ) ) {
@@ -972,14 +1002,15 @@ void			write_word_index( ostream&, off_t* );
 			// word.
 			//
 			stop_words->insert( new_strdup( w->first.c_str() ) );
-			words.erase( w );
+			words.erase( w++ );
 			continue;
 		}
+		++w;
 
 		//
 		// Compute the rank for this word in every file it's in.
 		//
-		double const factor = 10000.0 / info.occurrences_;
+		double const factor = (double)Rank_Factor / info.occurrences_;
 		TRANSFORM_EACH( word_info::file_list, info.files_, file )
 			file->rank_ = rank(
 				file->index_, file->occurrences_, factor
@@ -1076,9 +1107,11 @@ void			write_word_index( ostream&, off_t* );
 		i = file_info::begin(); i != file_info::end(); ++i
 	) {
 		offset[ file_index++ ] = o.tellp();
-		o	<< bcd( (*i)->dir_index() )
-			<< (*i)->file_name() << '\0' << bcd( (*i)->size() )
-			<< bcd( (*i)->num_words() ) << (*i)->title() << '\0';
+		o	<< enc_int( (*i)->dir_index() )
+			<< (*i)->file_name() << '\0'
+			<< enc_int( (*i)->size() )
+			<< enc_int( (*i)->num_words() )
+			<< (*i)->title() << '\0';
 	}
 }
 
@@ -1092,86 +1125,16 @@ void			write_word_index( ostream&, off_t* );
 //
 //	Write the index to the given ostream.  The index file is written in
 //	such a way so that it can be mmap'd and used instantly with no parsing
-//	or other processing.  The format of an index file is:
-//
-//		long	num_unique_words;
-//		off_t	word_offset[ num_unique_words ];
-//		long	num_stop_words;
-//		off_t	stop_word_offset[ num_stop_words ];
-//		long	num_directories;
-//		off_t	directory_offset[ num_directories ];
-//		long	num_files;
-//		off_t	file_offset[ num_files ];
-//		long	num_meta_names;
-//		off_t	meta_name_offset[ num_meta_names ];
-//			(word index)
-//			(stop-word index)
-//			(directory index)
-//			(file index)
-//			(meta-name index)
-//
-//	The word index is a list of all the words indexed in alphabetical
-//	order.  Each entry is of the form:
-//
-//		word\0{data}...\xFF
-//
-//	that is: a null-terminated word followed by one or more data entries
-//	followed by an \xFF byte where a data entry is:
-//
-//		{I}[\xEE{M}...\xEE]{O}{R}
-//
-//	that is: a file-index (I) followed by zero or more meta-IDs (M)
-//	surrounded by \xEE bytes followed by the number of occurrences in the
-//	file (O) followed by a rank (R).  The integers are in BCD (binary coded
-//	decimal) not raw binary.  A BCD integer that has an odd number of
-//	digits is terminated by a low-order nybble with the value \xA; an
-//	integer that has an even number of digits is terminated by a a byte
-//	with the value \xAA.  (These values were chosen because they are
-//	invalid BCD.  All other values \xA0 through \xFE are reserved for
-//	future use.)  The file-index is an index into the file offset table;
-//	the meta-IDs, if present, are unique integers identifying which meta
-//	name(s) a word is associated with in the meta-name index.
-//
-//	The stop-word index is a list of all the stop words (either the built-
-//	in list or the list supplied from a file, plus those that exceed either
-//	the file limit or word percentage) in alphabetical order.  Each entry
-//	is of the form:
-//
-//		word\0
-//
-//	where the word is terminated by a null byte.
-//
-//	The directory index is a list of all the directories in the order
-//	encountered.  Each entry is of the form:
-//
-//		path\0
-//
-//	where the path is terminated by a null byte.
-//
-//	The file index is a list of file information.  Each entry is of the
-//	form:
-//
-//		{D}file_name\0{S}{W}file_title\0
-//
-//	that is: a directory-index (D) followed by a null-terminated file name
-//	followed by the file's size in bytes (S) followed by the number of
-//	words in the file (W) followed by the file's null-terminated title.
-//	The integers are in BCD format.
-//
-//	The meta-name index is a list of all the meta names (in alphabetical
-//	order) encountered during indexing of all the files.  Each meta-name is
-//	followed by its numeric ID that is simply a unique integer to identify
-//	it.  Each entry is of the form:
-//
-//		meta_name\0{I}
-//
-//	that is: a null-terminated meta-name followed by the ID (I) in BCD
-//	format.
+//	or other processing.
 //
 // PARAMETERS
 //
 //	o	The ostream to write the index to.
 //
+// SEE ALSO
+//
+//	swish++.index(4)
+//
 //*****************************************************************************
 {
 	if ( !( num_unique_words = words.size() ) )
@@ -1220,7 +1183,7 @@ void			write_word_index( ostream&, off_t* );
 	register int meta_index = 0;
 	FOR_EACH( meta_map, meta_names, m ) {
 		offset[ meta_index++ ] = o.tellp();
-		o << m->first << '\0' << bcd( m->second );
+		o << m->first << '\0' << enc_int( m->second );
 	}
 }
 
@@ -1335,15 +1298,21 @@ void			write_word_index( ostream&, off_t* );
 #else
 		o << w->first << '\0';
 #endif
+		bool continues = false;
 		word_info const &info = w->second;
 		FOR_EACH( word_info::file_list, info.files_, file ) {
-			o << bcd( file->index_ );
+			if ( continues )
+				o << Word_Entry_Continues_Marker;
+			else
+				continues = true;
+			o << enc_int( file->index_ )
+			  << enc_int( file->occurrences_ )
+			  << enc_int( file->rank_ );
 			if ( !file->meta_ids_.empty() )
 				file->write_meta_ids( o );
-			o << bcd( file->occurrences_ ) << bcd( file->rank_ );
 		}
 
-		o << '\xFF';
+		o << Stop_Marker;
 	}
 }
 
@@ -1357,29 +1326,30 @@ ostream& usage( ostream &err ) {
 	err << "usage: " << me << " [options] dir ... file ...\n"
 	"options: (unambiguous abbreviations may be used for long options)\n"
 	"========\n"
-	"-?     | --help            : Print this help message\n"
-	"-A     | --no-assoc-meta   : Don't associate meta names [default: do]\n"
-	"-c f   | --config-file f   : Name of configuration file [default: " << ConfigFile_Default << "]\n"
-	"-e m:p | --pattern m:p     : Module and file pattern to index [default: none]\n"
-	"-E p   | --no-pattern p    : File pattern not to index [default: none]\n"
-	"-f n   | --word-files n    : Word/file maximum [default: infinity]\n"
-	"-F n   | --files-reserve n : Reserve space for number of files [default: " << FilesReserve_Default << "]\n"
-	"-g n   | --files-grow n    : Number or percentage to grow by [default: " << FilesGrow_Default << "]\n"
-	"-i f   | --index-file f    : Name of index file to use [default: " << IndexFile_Default << "]\n"
-	"-I     | --incremental     : Add files/words to index [default: replace]\n"
+	"-?     | --help             : Print this help message\n"
+	"-A     | --no-assoc-meta    : Don't associate meta names [default: do]\n"
+	"-c f   | --config-file f    : Name of configuration file [default: " << ConfigFile_Default << "]\n"
+	"-e m:p | --pattern m:p      : Module and file pattern to index [default: none]\n"
+	"-E p   | --no-pattern p     : File pattern not to index [default: none]\n"
+	"-f n   | --word-files n     : Word/file maximum [default: infinity]\n"
+	"-F n   | --files-reserve n  : Reserve space for number of files [default: " << FilesReserve_Default << "]\n"
+	"-g n   | --files-grow n     : Number or percentage to grow by [default: " << FilesGrow_Default << "]\n"
+	"-i f   | --index-file f     : Name of index file to use [default: " << IndexFile_Default << "]\n"
+	"-I     | --incremental      : Add files/words to index [default: replace]\n"
 #ifndef	PJL_NO_SYMBOLIC_LINKS
-	"-l     | --follow-links    : Follow symbolic links [default: don't]\n"
+	"-l     | --follow-links     : Follow symbolic links [default: don't]\n"
 #endif
-	"-m m   | --meta m          : Meta name to index [default: all]\n"
-	"-M m   | --no-meta m       : Meta name not to index [default: none]\n"
-	"-p n   | --word-percent n  : Word/file percentage [default: 100]\n"
-	"-r     | --no-recurse      : Don't index subdirectories [default: do]\n"
-	"-s f   | --stop-file f     : Stop-word file to use instead of built-in default\n"
-	"-S     | --dump-stop       : Dump built-in stop-words, exit\n"
-	"-t n   | --title-lines n   : Lines to look for titles [default: " << TitleLines_Default << "]\n"
-	"-T d   | --temp-dir d      : Directory for temporary files [default: " << TempDirectory_Default << "]\n"
-	"-v n   | --verbosity n     : Verbosity level [0-4; default: 0]\n"
-	"-V     | --version         : Print version number, exit\n";
+	"-m m   | --meta m           : Meta name to index [default: all]\n"
+	"-M m   | --no-meta m        : Meta name not to index [default: none]\n"
+	"-p n   | --word-percent n   : Word/file percentage [default: 100]\n"
+	"-r     | --no-recurse       : Don't index subdirectories [default: do]\n"
+	"-s f   | --stop-file f      : Stop-word file to use instead of built-in default\n"
+	"-S     | --dump-stop        : Dump built-in stop-words, exit\n"
+	"-t n   | --title-lines n    : Lines to look for titles [default: " << TitleLines_Default << "]\n"
+	"-T d   | --temp-dir d       : Directory for temporary files [default: " << TempDirectory_Default << "]\n"
+	"-v n   | --verbosity n      : Verbosity level [0-4; default: 0]\n"
+	"-V     | --version          : Print version number, exit\n"
+	"-W n   | --word-threshold n : Words to make partial indicies [default: " << WordThreshold_Default << "]\n";
 	indexer::all_mods_usage( err );
 	::exit( Exit_Usage );
 	return err;			// just to make the compiler happy
