@@ -19,7 +19,7 @@
 **	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#ifdef	mod_html
+#ifdef	MOD_html
 
 // standard
 #include <cctype>
@@ -27,6 +27,7 @@
 
 // local
 #include "AssociateMeta.h"
+#include "charsets/unicode.h"
 #include "config.h"
 #include "encoded_char.h"
 #include "entities.h"
@@ -47,9 +48,8 @@ bool				HTML_indexer::dump_html_elements_opt_ = false;
 HTML_indexer::stack_type	HTML_indexer::element_stack_;
 ExcludeClass			exclude_class_names;
 
-bool	is_html_comment( encoded_char_range::const_iterator &pos );
-bool	skip_html_tag( encoded_char_range::const_iterator &pos );
-bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
+static bool is_html_comment( encoded_char_range::const_iterator &pos );
+static bool skip_html_tag( encoded_char_range::const_iterator &pos );
 
 //*****************************************************************************
 //
@@ -190,8 +190,7 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 		}
 	}
 
-	return	n < sizeof( iso8859_map ) / sizeof( iso8859_map[0] ) ?
-		iso8859_to_ascii( n ) : ' ';
+	return unicode_to_ascii( n );
 }
 
 //*****************************************************************************
@@ -377,7 +376,7 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 		// Is the HTML or XHTML tag a TITLE tag?
 		//
 		bool const found_title_tag =
-			tag_cmp( c, title_tag[ tag_index ] );
+			move_if_match( c, title_tag[ tag_index ], true );
 		skip_html_tag( c );			// skip until '>'
 		if ( !found_title_tag )			// wrong tag
 			continue;
@@ -417,7 +416,7 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 //
 //	e		The encoded text to index.
 //
-//	meta_id		The numeric ID of the META NAME the words index are to
+//	meta_id		The numeric ID of the meta name the words index are to
 //			to be associated with.
 //
 //*****************************************************************************
@@ -431,10 +430,10 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 		register char ch = *c++;
 		//
 		// If the character is an '&' (the start of a entity
-		// reference), convert the entity reference to ASCII;
-		// otherwise, convert the ISO 8859 character to ASCII.
+		// reference), convert the entity reference to ASCII.
 		//
-		ch = ch == '&' ? entity_to_ascii( c ) : iso8859_to_ascii( ch );
+		if ( ch == '&' )
+			ch = entity_to_ascii( c );
 
 		////////// Collect a word /////////////////////////////////////
 
@@ -523,7 +522,7 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 //
 //*****************************************************************************
 {
-	if ( tag_cmp( c, "!--" ) ) {
+	if ( move_if_match( c, "!--" ) ) {
 		while ( !c.at_end() )
 			if ( *c++ == '-' && !c.at_end() && *c == '-' ) {
 				encoded_char_range::const_iterator const d = c;
@@ -789,9 +788,9 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 
 	////////// Look for an ALT attribute //////////////////////////////////
 
-	if (	tag_cmp( name, "area" ) ||
-		tag_cmp( name, "img" ) ||
-		tag_cmp( name, "input" )
+	if (	move_if_match( name, "area", true ) ||
+		move_if_match( name, "img", true ) ||
+		move_if_match( name, "input", true )
 	) {
 		encoded_char_range alt_att = name;
 		if ( find_attribute( alt_att, "alt" ) )
@@ -801,13 +800,13 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 
 	////////// Parse a META element ///////////////////////////////////////
 
-	if ( tag_cmp( name, "meta" ) ) {
+	if ( move_if_match( name, "meta", true ) ) {
 		encoded_char_range name_att    = name;
 		encoded_char_range content_att = name;
 		if (	find_attribute( name_att, "name" ) &&
 			find_attribute( content_att, "content" )
 		) {
-			int meta_id;
+			int meta_id = No_Meta_ID;
 			if ( associate_meta ) {
 				//
 				// Do not index the words in the value of the
@@ -819,8 +818,7 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 				meta_id = find_meta( to_lower( name_att ) );
 				if ( meta_id == No_Meta_ID )
 					return;
-			} else
-				meta_id = No_Meta_ID;
+			}
 			//
 			// Index the words in the value of the CONTENT
 			// attribute marking them as being associated with the
@@ -833,7 +831,7 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 
 	////////// Look for a STANDBY attribute ///////////////////////////////
 
-	if ( tag_cmp( name, "object" ) ) {
+	if ( move_if_match( name, "object", true ) ) {
 		encoded_char_range standby_att = name;
 		if ( find_attribute( standby_att, "standby" ) )
 			index_words( standby_att );
@@ -842,7 +840,7 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 
 	////////// Look for a SUMMARY attribute ///////////////////////////////
 
-	if ( tag_cmp( name, "table" ) ) {
+	if ( move_if_match( name, "table", true ) ) {
 		encoded_char_range summary_att = name;
 		if ( find_attribute( summary_att, "summary" ) )
 			index_words( summary_att );
@@ -959,44 +957,6 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 	return false;
 }
 
-//*****************************************************************************
-//
-// SYNOPSIS
-//
-	bool tag_cmp(
-		encoded_char_range::const_iterator &c,
-		register char const *tag
-	)
-//
-// DESCRIPTION
-//
-//	Compares the tag name starting at the given iterator to the given
-//	string.  Case is irrelevant.
-//
-// PARAMETERS
-//
-//	c	The iterator to use.  It is presumed to be positioned at the
-//		first character after the '<'.  If the tag name matches, it is
-//		repositioned at the first character past the name; otherwise,
-//		it is not touched.
-//
-//	tag	The string to compare against; it must be in lower case.
-//
-// RETURN VALUE
-//
-//	Returns true only if the tag matches.
-//
-//*****************************************************************************
-{
-	encoded_char_range::const_iterator d = c;
-	while ( *tag && !d.at_end() && *tag == to_lower( *d ) )
-		++tag, ++d;
-	if ( *tag )
-		return false;
-	c = d;
-	return true;
-}
-
 //*****************************************************************************
 //
 // SYNOPSIS
@@ -1015,8 +975,8 @@ bool	tag_cmp( encoded_char_range::const_iterator &pos, char const *tag );
 {
 	o <<
 	"---------------------------- HTML options -------------------------------------\n"
-	"-C c   | --no-class c      : Class name not to index [default: none]\n"
-	"-H     | --dump-html       : Dump built-in recognized HTML/XHTML elements, exit\n";
+	"-C c   | --no-class c       : Class name not to index [default: none]\n"
+	"-H     | --dump-html        : Dump built-in recognized HTML/XHTML elements, exit\n";
 }
 
-#endif	/* mod_html */
+#endif	/* MOD_html */
