@@ -19,7 +19,7 @@
 **	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#ifdef	mod_mail
+#ifdef	MOD_mail
 
 // standard
 #include <algorithm>			/* for copy() */
@@ -32,15 +32,16 @@
 #include "AssociateMeta.h"
 #include "auto_vec.h"
 #include "config.h"
+#include "encoded_char.h"
 #include "FilterAttachment.h"
 #include "IncludeMeta.h"
 #include "less.h"
 #include "meta_map.h"
-#ifdef	mod_html
+#ifdef	MOD_html
 #include "mod/html/mod_html.h"
 #endif
 #include "mod_mail.h"
-#ifdef	mod_rtf
+#ifdef	MOD_rtf
 #include "mod/rtf/mod_rtf.h"
 #endif
 #include "TitleLines.h"
@@ -53,21 +54,15 @@ using namespace PJL;
 using namespace std;
 #endif
 
+FilterAttachment		attachment_filters;
 mail_indexer::stack_type	mail_indexer::boundary_stack_;
 bool				mail_indexer::did_last_header;
 
-bool				header_cmp(
-					char const *&pos, char const *end,
-					char const *tag
-				);
-
-FilterAttachment		attachment_filters;
-
 //*****************************************************************************
 //
 // SYNOPSIS
 //
-	bool boundary_cmp(
+	static bool boundary_cmp(
 		register char const *c, register char const *end,
 		register char const *boundary
 	)
@@ -195,7 +190,7 @@ FilterAttachment		attachment_filters;
 		char const *const nl = find_newline( c, file.end() );
 		if ( nl == file.end() )
 			break;
-		if ( header_cmp( c, nl, "subject:" ) )
+		if ( move_if_match( c, nl, "subject:", true ) )
 			return tidy_title( c, nl );	// found the Subject
 
 		c = skip_newline( nl, file.end() );
@@ -208,46 +203,6 @@ FilterAttachment		attachment_filters;
 	return 0;
 }
 
-//*****************************************************************************
-//
-// SYNOPSIS
-//
-	bool header_cmp(
-		char const *&c, register char const *end,
-		register char const *header
-	)
-//
-// DESCRIPTION
-//
-//	Compares the header name starting at the given iterator to the given
-//	string.  Case is irrelevant.
-//
-// PARAMETERS
-//
-//	c	The pointer presumed to be positioned at the first character
-//		after the '<'.  If the tag name matches, it is repositioned at
-//		the first character past the name; otherwise, it is not
-//		touched.
-//
-//	end	The pointer to the end of the file.
-//
-//	header	The string to compare against; it must be in lower case.
-//
-// RETURN VALUE
-//
-//	Returns true only if the header matches.
-//
-//*****************************************************************************
-{
-	register char const *d = c;
-	while ( *header && d != end && *header == to_lower( *d ) )
-		++header, ++d;
-	if ( *header )
-		return false;
-	c = d;
-	return true;
-}
-
 //*****************************************************************************
 //
 // SYNOPSIS
@@ -357,12 +312,28 @@ could_not_filter:
 			auto_vec<char> const value(
 				to_lower_r( kv.value_begin, kv.value_end )
 			);
-			if ( ::strstr( value, "quoted-printable" ) )
-				type.encoding_ = Quoted_Printable;
-			else if ( ::strstr( value, "base64" ) )
-				type.encoding_ = Base64;
-			else if ( ::strstr( value, "binary" ) )
+			if ( ::strstr( value, "binary" ) )
 				type.encoding_ = Binary;
+			else if ( ::strstr( value, "base64" ) )
+#ifdef	ENCODING_base64
+				type.encoding_ = encoding_base64;
+#else
+				// Since Base64 encoding wasn't compiled in, we
+				// need to make it not indexable: set the
+				// encoding to binary.
+				//
+				type.encoding_ = Binary;
+#endif
+#ifdef	ENCODING_quoted_printable
+			else if ( ::strstr( value, "quoted-printable" ) )
+				type.encoding_ = encoding_quoted_printable;
+#else
+			// Treat quoted-printable as plain text since it *is*
+			// mostly plain text.  (This is the best that can be
+			// done if the encoding isn't compiled in and it's
+			// better than treating the text as binary and not
+			// indexing it at all.)
+#endif
 			continue;
 		}
 
@@ -382,6 +353,33 @@ could_not_filter:
 				continue;
 			string const mime_type( s, ::strcspn( s, "; \n\r\t" ) );
 
+			//
+			// Extract the charset, if any.
+			//
+			char const *charset = ::strstr( value, "charset=" );
+			if ( charset && *(charset += 8) ) {
+				if ( *charset == '"' )
+					++charset;
+				//
+				// We don't explicitly check for us-ascii since
+				// that's the default.
+				//
+				if ( !::strcmp( charset, "iso8859-1" ) )
+					type.charset_ = ISO_8859_1;
+				else if ( !::strcmp( charset, "utf-7" ) )
+#ifdef	CHARSET_utf7
+					type.charset_ = charset_utf7;
+#else
+					goto not_indexable;
+#endif
+				else if ( !::strcmp( charset, "utf-8" ) )
+#ifdef	CHARSET_utf8
+					type.charset_ = charset_utf8;
+#else
+					goto not_indexable;
+#endif
+			}
+
 			//
 			// See if there's a filter for the MIME type: if so,
 			// set up to use it.  Note that a filter can override
@@ -408,14 +406,10 @@ could_not_filter:
 			//
 			if ( mime_type == "text/plain" )
 				type.content_type_ = Text_Plain;
-#ifdef	mod_rtf
 			else if ( mime_type == "text/enriched" )
 				type.content_type_ = Text_Enriched;
-#endif
-#ifdef	mod_html
 			else if ( mime_type == "text/html" )
 				type.content_type_ = Text_HTML;
-#endif
 			else if ( ::strstr( value, "vcard" ) )
 				type.content_type_ = Text_vCard;
 			else if ( mime_type == "message/rfc822" )
@@ -428,10 +422,8 @@ could_not_filter:
 			//
 			else if ( ::strstr( value, "multipart/" ) ) {
 				char const *b = ::strstr( value, "boundary=" );
-				if ( !b || !*(b += 9) ) {
-					type.content_type_ = Not_Indexable;
-					continue;	// weird case
-				}
+				if ( !b || !*(b += 9) )	// weird case
+					goto not_indexable;
 				//
 				// Erase everything (including any surrounding
 				// quotes) except the boundary string from the
@@ -455,27 +447,29 @@ could_not_filter:
 				// It's not a Content-Type we know anything
 				// about, so it's not indexable.
 				//
-				type.content_type_ = Not_Indexable;
+not_indexable:			type.content_type_ = Not_Indexable;
 			}
 		}
 
 		////////// Index the value of the header //////////////////////
 
-		int meta_id;
+		//
+		// Potentially index the words in the value of the header where
+		// they are associated with the name of the header as a meta
+		// name.
+		//
+		int meta_id = No_Meta_ID;
 		if ( associate_meta ) {
 			//
-			// Potentially index the words in the value of the
-			// header where they are associated with the name of
-			// the header as a meta name.
+			// Do not index the words in the value of the header if
+			// either the name of the header (canonicalized to
+			// lower case) is among the set of meta names to
+			// exclude or not among the set to include.
 			//
 			if ( (meta_id = find_meta( kv.key )) == No_Meta_ID )
 				continue;
-		} else
-			meta_id = No_Meta_ID;
-
-		encoded_char_range const e(
-			kv.value_begin, kv.value_end, Seven_Bit
-		);
+		}
+		encoded_char_range const e( kv.value_begin, kv.value_end );
 		indexer::index_words( e, meta_id );
 	}
 
@@ -541,6 +535,7 @@ could_not_filter:
 		//
 		// Index the words between the boundaries.
 		//
+		encoded_char_range::decoder::reset_all();
 		encoded_char_range const part( part_begin, part_end );
 		index_words( part );
 
@@ -599,7 +594,7 @@ could_not_filter:
 		// being associated with the name of the type.
 		//
 		encoded_char_range const e(
-			kv.value_begin, kv.value_end, Eight_Bit
+			kv.value_begin, kv.value_end, ISO_8859_1, Eight_Bit
 		);
 		indexer::index_words( e, meta_id );
 	}
@@ -609,9 +604,8 @@ could_not_filter:
 //
 // SYNOPSIS
 //
-	/* virtual */ void mail_indexer::index_words(
-		encoded_char_range const &e, int
-	)
+	/* virtual */
+	void mail_indexer::index_words( encoded_char_range const &e, int )
 //
 // DESCRIPTION
 //
@@ -638,7 +632,9 @@ could_not_filter:
 	// Create a new encoded_char_range having the same range but the
 	// Content-Transfer-Encoding given in the headers.
 	//
-	encoded_char_range const e2( c.pos(), c.end_pos(), type.encoding_ );
+	encoded_char_range const e2(
+		c.pos(), c.end_pos(), type.charset_, type.encoding_
+	);
 
 	switch ( type.content_type_ ) {
 
@@ -649,14 +645,14 @@ could_not_filter:
 		case Text_Plain:
 			indexer::index_words( e2 );
 			break;
-#ifdef	mod_rtf
+#ifdef	MOD_rtf
 		case Text_Enriched: {
 			static indexer &rtf = *indexer::find_indexer( "RTF" );
 			rtf.index_words( e2 );
 			break;
 		}
 #endif
-#ifdef	mod_html
+#ifdef	MOD_html
 		case Text_HTML: {
 			static indexer &html = *indexer::find_indexer( "HTML" );
 			html.index_words( e2 );
@@ -734,7 +730,7 @@ could_not_filter:
 
 	char const *header_begin, *header_end, *nl;
 
-	while ( 1 ) {
+	while ( true ) {
 		if ( (nl = find_newline( c, end )) == end )
 			return false;
 		//
@@ -768,7 +764,7 @@ could_not_filter:
 	if ( ++c == end )			// skip past the ':'
 		return false;
 	kv->value_begin = c;
-	while ( 1 ) {
+	while ( true ) {
 		if ( (c = skip_newline( nl, end )) == end )
 			break;
 		//
@@ -814,4 +810,4 @@ more_headers:
 	return true;
 }
 
-#endif	/* mod_mail */
+#endif	/* MOD_mail */
