@@ -35,7 +35,6 @@
 
 // local
 #include "auto_vec.h"
-#include "bcd.h"
 #include "classic_formatter.h"
 #include "config.h"
 #include "exit_codes.h"
@@ -140,9 +139,9 @@ User		user;
 
 void		become_daemon();
 #endif
-void		dump_single_word( char const*, ostream& = cout );
-void		dump_word_window( char const*, int, int, ostream& = cout );
-ostream&	write_file_info( ostream&, char const* );
+static void	dump_single_word( char const*, ostream& = cout );
+static void	dump_word_window( char const*, int, int, ostream& = cout );
+static ostream&	write_file_info( ostream&, char const* );
 
 inline omanip< char const* > index_file_info( int index ) {
 	return omanip< char const* >( write_file_info, files[ index ] );
@@ -259,6 +258,7 @@ inline omanip< char const* > index_file_info( int index ) {
 	/////////// Load index file ///////////////////////////////////////////
 
 	mmap_file const the_index( index_file_name );
+	the_index.behavior( mmap_file::random );
 	if ( !the_index ) {
 		error()	<< "could not read index from \""
 			<< index_file_name << "\"\n";
@@ -301,7 +301,7 @@ inline omanip< char const* > index_file_info( int index ) {
 //
 //*****************************************************************************
 {
-	auto_vec< char > const lower_word( to_lower_r( word ) );
+	auto_vec<char> const lower_word( to_lower_r( word ) );
 	less< char const* > const comparator;
 
 	if ( !is_ok_word( word ) || ::binary_search(
@@ -474,7 +474,7 @@ inline omanip< char const* > index_file_info( int index ) {
 		//
 		// Compute the highest rank and the normalization factor.
 		//
-		int highest_rank = sorted[0].second;
+		int const highest_rank = sorted[0].second;
 		double const normalize = 100.0 / highest_rank;
 		//
 		// Print the sorted results skipping some if requested to and
@@ -485,9 +485,12 @@ inline omanip< char const* > index_file_info( int index ) {
 			i != sorted.end() && max_results-- > 0 && out;
 			++i
 		) {
+			// cast gets rid of warning
+			int rank = static_cast<int>( i->second * normalize );
+			if ( !rank )
+				rank = 1;
 			format->result(
-				// cast gets rid of warning
-				static_cast<int>( i->second * normalize ),
+				rank,
 				file_info(
 					reinterpret_cast<unsigned char const*>(
 						files[ i->first ]
@@ -854,7 +857,7 @@ ostream& usage( ostream &err ) {
 	"-d   | --dump-words       : Dump query word indices, exit\n"
 	"-D   | --dump-index       : Dump entire word index, exit\n"
 	"-f n | --word-files n     : Word/file maximum [default: infinity]\n"
-	"-F f | --format f         : Output format [default: classic]\n"
+	"-F f | --format f         : Results format [default: classic]\n"
 #ifdef SEARCH_DAEMON
 	"-G s | --group s          : Daemon group to run as [default: " << Group_Default << "]\n"
 #endif
