@@ -31,6 +31,7 @@
 #include <string>
 #include <ctime>			/* needed by sys/resource.h */
 #include <sys/time.h>			/* needed by FreeBSD systems */
+#include <sys/types.h>			/* needed by FreeBSD systems */
 #include <sys/resource.h>
 #include <sys/stat.h>
 #include <unistd.h>			/* for _exit(2), geteuid(2) */
@@ -217,7 +218,7 @@ private:
 //
 //*****************************************************************************
 
-extern struct stat	stat_buf;		// somplace to do a stat(2) in
+extern struct stat	stat_buf;		// someplace to do a stat(2) in
 
 inline bool	file_exists( char const *path ) {
 			return ::stat( path, &stat_buf ) != -1;
@@ -279,6 +280,8 @@ inline std::ostream&	error_string( std::ostream &o = std::cerr ) {
 			<< __FILE__ << "\", line " << __LINE__ \
 			<< ": internal error:\n"
 
+#define	NUM_ELEMENTS(a)	(sizeof (a) / sizeof( (a)[0] ))
+
 inline std::ostream&	report_error( std::ostream &o = std::cerr ) {
 				o << "please report this error\n";
 				::_exit( Exit_Internal_Error );
@@ -291,19 +294,34 @@ inline char*		new_strdup( char const *s ) {
 				);
 			}
 
-			// ensure function semantics: 'c' is expanded once
-inline bool		is_alnum( char c )	{ return isalnum( c ); }
-inline bool		is_alpha( char c )	{ return isalpha( c ); }
-inline bool		is_digit( char c )	{ return isdigit( c ); }
-inline bool		is_punct( char c )	{ return ispunct( c ); }
-inline bool		is_space( char c )	{ return isspace( c ); }
-inline bool		is_upper( char c )	{ return isupper( c ); }
-inline bool		is_xdigit( char c )	{ return isxdigit( c ); }
-inline char		to_lower( char c )	{ return tolower( c ); }
-extern char*		to_lower( char const* );
-extern char*		to_lower_r( char const* );
-extern char*		to_lower( char const *begin, char const *end );
-extern char*		to_lower_r( char const *begin, char const *end );
+		// ensure function semantics: 'c' is expanded once
+inline bool	is_alnum( char c ) {
+			return isalnum( static_cast<unsigned char>( c ) );
+		}
+inline bool	is_alpha( char c ) {
+			return isalpha( static_cast<unsigned char>( c ) );
+		}
+inline bool	is_digit( char c ) {
+			return isdigit( static_cast<unsigned char>( c ) );
+		}
+inline bool	is_punct( char c ) {
+			return ispunct( static_cast<unsigned char>( c ) );
+		}
+inline bool	is_space( char c ) {
+			return isspace( static_cast<unsigned char>( c ) );
+		}
+inline bool	is_upper( char c ) {
+			return isupper( static_cast<unsigned char>( c ) );
+		}
+inline bool	is_xdigit( char c ) {
+			return isxdigit( static_cast<unsigned char>( c ) );
+		}
+
+inline char	to_lower( char c ) { return tolower( c ); }
+extern char*	to_lower( char const* );
+extern char*	to_lower_r( char const* );
+extern char*	to_lower( char const *begin, char const *end );
+extern char*	to_lower_r( char const *begin, char const *end );
 
 #define	FOR_EACH(T,C,I) \
 	for ( T::const_iterator I = (C).begin(); I != (C).end(); ++I )
